@@ -105,6 +105,18 @@ def put_to_sent_sms(name, number, uniqueid, groupid, tme, message):
     rtcom.rtcom_el_event_free(ctypes.byref(event))
     #glib.g_object_unref(el)
 
+class xEntry(gtk.Entry):
+    def __init__(self, allowedchars):
+        gtk.Entry.__init__(self)
+        self.allowedchars=allowedchars
+        self.connect("changed", self.charcheck, None)
+
+    def charcheck(self, widget, string, *args):
+        pos = widget.get_position()
+        char = widget.get_chars(pos, pos + 1)
+        if char not in self.allowedchars:
+            widget.select_region(pos, pos + 1)
+            widget.delete_selection()
 
 class EntryDialog( gtk.Dialog):
 
@@ -130,13 +142,13 @@ class EntryDialog( gtk.Dialog):
 
         if message:
 
-            label = gtk.Label(message)
+            label = gtk.Label('Mobile Number')
 
             box.pack_start(label)
 
             label.show()
 
-        self.entry = gtk.Entry()
+        self.entry = xEntry("+1234567890.")
 
         self.entry.set_text(default_text)
 
@@ -146,13 +158,27 @@ class EntryDialog( gtk.Dialog):
 
         self.entry.grab_focus()
 	
+	label = gtk.Label('Message')
+
+        box.pack_start(label)
+
+        label.show()	
+
 	self.entry2 = gtk.Entry()
 
+	self.entry2.set_max_length(160)
+
 	box.pack_start(self.entry2)
 
         self.entry2.show()
 
-	self.entry3 = gtk.Entry()
+	label = gtk.Label('Seconds since you should have sent TXT')
+
+        box.pack_start(label)
+
+        label.show()
+
+	self.entry3 = xEntry("1234567890.")
 
 	box.pack_start(self.entry3)
 
